#!/usr/bin/python3

# Copyright (C) 2014-2020, Josef Hahn
#
# This file is part of Yaji.
#
# Yaji is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Yaji is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Yaji.  If not, see <http://www.gnu.org/licenses/>.

import ___sampleapp  # this is just an internal hack - just ignore it and don't copy it!

import yaji


class Application(yaji.Application):

    def __init__(self):
        super().__init__(head1="Yaji Sample", head2="menus", stop_implicitly_when_browser_closed=True)
        self.__mynumber = self.create_datastore()
        self.__mynumber.setvalue(5)
        self.__mystepsize = 1
        self.__frozen = False
        self.setbodyleft(yaji.VerticalStack(
            yaji.Spacer(vstretch=1),
            yaji.View('Label', label=self.binddata(self.__mynumber),
                      style='font-size:5em;letter-spacing:3pt;text-align:center;', hstretch=1),
            yaji.Spacer(vstretch=1),
            hstretch=1))
        self.setactions([yaji.Action("decrease", yaji.BackendFunction("mynumber_decrease"),
                                     icon=yaji.Icon(by_symbol="▼")),
                         yaji.Action("increase", yaji.BackendFunction("mynumber_increase"),
                                     icon=yaji.Icon(by_symbol="▲"))])
        self.__myburgermenu = self.create_datastore()
        self.__myburgermenu.appendrow(values=[yaji.Action("change stepsize",
                                                          yaji.BackendFunction("change_stepsize"))])
        self.freezeaction = self.__myburgermenu.appendrow(values=[None])
        self.__myburgermenu.appendrow(values=[yaji.Separator()])
        self.__myburgermenu.appendrow(values=[yaji.Action("reset", yaji.BrowserFunction("mynumberreset"))])
        presetsmenu = self.__myburgermenu.appendrow(values=[yaji.Submenu("presets")])
        presetsmenu.appendrow(values=[yaji.Action("5", yaji.BackendFunction("mynumber_set", {'value': 5}))])
        presetsmenu.appendrow(values=[yaji.Action("35", yaji.BackendFunction("mynumber_set", {'value': 35}))])
        presetsmenu.appendrow(values=[yaji.Action("42", yaji.BackendFunction("mynumber_set", {'value': 42}))])
        self.__myburgermenu.appendrow(values=[yaji.Separator()])
        self.__myburgermenu.appendrow(values=[yaji.Action("some disabled action",
                                                          yaji.BrowserFunction("dummy"), disabled=True)])
        self.__myburgermenu.appendrow(values=[yaji.Action("some invisible action",
                                                          yaji.BrowserFunction("dummy"), invisible=True)])
        self.setheadcontrol(yaji.View("PopupMenuButton", actions=self.__myburgermenu))
        self.__refresh_freezeaction()

    def __refresh_freezeaction(self):
        a = yaji.Action("freeze", yaji.BackendFunction("freeze", {'val': not self.__frozen}),
                        checkable=True, checked=self.__frozen)
        self.freezeaction.setvalue(a)

    def __set_mynumber(self, v):
        if not self.__frozen:
            self.__mynumber.setvalue(v)

    @yaji.RequestHandler.for_urls(auto=True)
    def _do_mynumber_increase(self):
        self.__set_mynumber(self.__mynumber.getvalue() + self.__mystepsize)

    @yaji.RequestHandler.for_urls(auto=True)
    def _do_mynumber_decrease(self):
        self.__set_mynumber(self.__mynumber.getvalue() - self.__mystepsize)

    @yaji.RequestHandler.for_urls(auto=True)
    def _do_mynumber_reset(self):
        self.__set_mynumber(0)

    @yaji.RequestHandler.for_urls(auto=True)
    def _do_mynumber_set(self, value: int):
        self.__set_mynumber(value)

    @yaji.RequestHandler.for_urls(auto=True)
    def _do_freeze(self, val: bool):
        self.__frozen = val
        self.__refresh_freezeaction()

    @yaji.RequestHandler.for_urls(auto=True)
    @yaji.RequestHandler.run_downstream()
    def _do_change_stepsize(self):
        x = None
        while not x:
            r = self.userfeedback.inputdialog("Please enter a new step size.", str(self.__mystepsize))
            if not r:
                return
            try:
                x = int(r)
            except ValueError:
                pass
        self.__mystepsize = x


if __name__ == '__main__':
    Application().start()
