#!/usr/bin/python3

# Copyright (C) 2014-2020, Josef Hahn
#
# This file is part of Yaji.
#
# Yaji is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Yaji is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Yaji.  If not, see <http://www.gnu.org/licenses/>.

import ___sampleapp  # this is just an internal hack - just ignore it and don't copy it!

import yaji


class Application(yaji.Application):

    def __init__(self):
        super().__init__(head1="Yaji Sample", head2="simple widgets", stop_implicitly_when_browser_closed=True)

        loremipsum = ("Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut"
                      " labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco"
                      " laboris nisi ut aliquip ex ea commodo consequat. Duis aute irure dolor in reprehenderit in"
                      " voluptate velit esse cillum dolore eu fugiat nulla pariatur. Excepteur sint occaecat cupidatat"
                      " non proident, sunt in culpa qui officia deserunt mollit anim id est laborum.")

        with self.create_clientlocal_datastore("somedata") as somedata:  # some widgets directly use a datasource
            somedata.appendcolumn(values=["foonode", "barnode", "baznode"])

        self.setbodyleft(yaji.View('ScrollView', body=yaji.VerticalStack(

            yaji.View(label="Label", style="font-size:1.4em"),
            yaji.View('Label', label="Hallo Welt."),

            yaji.View(label="Button", style="font-size:1.4em"),
            yaji.View('Button', label="Go"),

            yaji.View(label="PopupMenuButton", style="font-size:1.4em"),
            yaji.View('PopupMenuButton', actions=[
                yaji.Action('Foo', yaji.BrowserFunction("clove.messageDialog", [{'message': 'Foo!'}])),
                yaji.Action('Bar', yaji.BrowserFunction("clove.messageDialog", [{'message': 'Bar!'}])),
            ]),

            yaji.View(label="Form", style="font-size:1.4em"),
            yaji.View('Form', sections=[
                yaji.View('EditBox', formSectionLabel="Foo"),
                yaji.View('EditBox', formSectionLabel="Bar"),
            ]),

            yaji.View(label="ScrollView", style="font-size:1.4em"),
            yaji.View('ScrollView', body=yaji.View(label=loremipsum), height='70pt'),

            yaji.View(label="ListView", style="font-size:1.4em"),
            # btw: ListView, TableView and TreeView have many common properties
            yaji.View('ListView', datasource=somedata),

            yaji.View(label="TableView", style="font-size:1.4em"),
            yaji.View('TableView', datasource=somedata, editOnGesture=True, allowSelection=True),

            yaji.View(label="TreeView", style="font-size:1.4em"),
            yaji.View('TreeView', datasource=somedata, showChangeMenu=True, allowSelection=True),

            yaji.View(label="CheckButton", style="font-size:1.4em"),
            yaji.View('CheckButton', label="Foo"),

            yaji.View(label="RadioButton", style="font-size:1.4em"),
            yaji.View('RadioButton', label="Foo", group='myradiogroup'),
            yaji.View('RadioButton', label="Bar", group='myradiogroup'),

            yaji.View(label="EditBox", style="font-size:1.4em"),
            yaji.View('EditBox', text="Lorem ipsum"),

            yaji.View(label="MultilineEditBox", style="font-size:1.4em"),
            yaji.View('MultilineEditBox', text=loremipsum),

            yaji.View(label="ImageView", style="font-size:1.4em"),
            yaji.View('ImageView', source='static/yaji.png'),

            yaji.View(label="TabView", style="font-size:1.4em"),
            yaji.View('TabView', tabs=[
                yaji.View('Label', label="Tab 1", tabLabel='1st'),
                yaji.View('Label', label="Tab 2", tabLabel='2nd'),
            ]),

            yaji.View(label="Carousel", style="font-size:1.4em"),
            yaji.View('Carousel', tabs=[
                yaji.View('Label', label="Tab 1"),
                yaji.View('Label', label="Tab 2"),
            ]),

            yaji.View(label="Slider", style="font-size:1.4em"),
            yaji.View('Slider', min=13, max=37, stepsize=2, value=21),

            yaji.View(label="Expander", style="font-size:1.4em"),
            yaji.View('Expander', collapsedLabel="Foobar", body=yaji.View(label="Hallo Welt!")),

            yaji.View(label="ProgressBar", style="font-size:1.4em"),
            yaji.View('ProgressBar', value=0.95),

            width='300pt')))


if __name__ == '__main__':
    Application().start()
